libmeminfo: Use more inclusive language

blacklist is replaced with excluded.

Test: none
Signed-off-by: Suren Baghdasaryan <surenb@google.com>
Change-Id: I9aeab878ca50c9a98e65aa6ab358cd27608b3dfb
diff --git a/procmeminfo.cpp b/procmeminfo.cpp
index 85c6562..9a2aaf9 100644
--- a/procmeminfo.cpp
+++ b/procmeminfo.cpp
@@ -43,7 +43,7 @@
 
 // List of VMA names that we don't want to process:
 //   - On ARM32, [vectors] is a special VMA that is outside of pagemap range.
-static const std::vector<std::string> g_blacklisted_vmas = {"[vectors]"};
+static const std::vector<std::string> g_excluded_vmas = {"[vectors]"};
 
 static void add_mem_usage(MemUsage* to, const MemUsage& from) {
     to->vss += from.vss;
@@ -148,8 +148,8 @@
     }
 
     auto collect_vmas = [&](const Vma& vma) {
-        if (std::find(g_blacklisted_vmas.begin(), g_blacklisted_vmas.end(), vma.name) ==
-                g_blacklisted_vmas.end()) {
+        if (std::find(g_excluded_vmas.begin(), g_excluded_vmas.end(), vma.name) ==
+                g_excluded_vmas.end()) {
             maps_.emplace_back(vma);
         }
     };
@@ -276,8 +276,8 @@
     if (!::android::procinfo::ReadMapFile(
                 maps_file, [&](uint64_t start, uint64_t end, uint16_t flags, uint64_t pgoff, ino_t,
                                const char* name) {
-                    if (std::find(g_blacklisted_vmas.begin(), g_blacklisted_vmas.end(), name) ==
-                            g_blacklisted_vmas.end()) {
+                    if (std::find(g_excluded_vmas.begin(), g_excluded_vmas.end(), name) ==
+                            g_excluded_vmas.end()) {
                         maps_.emplace_back(Vma(start, end, pgoff, flags, name));
                     }
                 })) {
diff --git a/tools/librank.cpp b/tools/librank.cpp
index d6a363e..cfc3f3c 100644
--- a/tools/librank.cpp
+++ b/tools/librank.cpp
@@ -150,7 +150,7 @@
 static std::map<std::string, LibRecord> g_libs;
 
 // List of library/map names that we don't want to show by default
-static const std::vector<std::string> g_blacklisted_libs = {"[heap]", "[stack]"};
+static const std::vector<std::string> g_excluded_libs = {"[heap]", "[stack]"};
 
 // Global flags affected by command line
 static uint64_t g_pgflags = 0;
@@ -200,9 +200,9 @@
             continue;
         }
 
-        // skip blacklisted library / map names
-        if (!g_all_libs && (std::find(g_blacklisted_libs.begin(), g_blacklisted_libs.end(),
-                                      map.name) != g_blacklisted_libs.end())) {
+        // skip excluded library / map names
+        if (!g_all_libs && (std::find(g_excluded_libs.begin(), g_excluded_libs.end(),
+                                      map.name) != g_excluded_libs.end())) {
             continue;
         }